﻿using Infrastructure.Options;
using Infrastructure.Repository.Mongo;
using MongoDB.Driver;

namespace Infrastructure.Extensions;

public static class MongoDbSetup
{
    public static IServiceCollection AddMongoDbSetup(
        this IServiceCollection services,
        IConfiguration configuration)
    {
        ArgumentNullException.ThrowIfNull(services);

        ArgumentNullException.ThrowIfNull(configuration);

        var mongoDbOptions = configuration.GetSection(MongoDbOptions.Name).Get<MongoDbOptions>();
        if (mongoDbOptions is null || !mongoDbOptions.IsEnable)
        {
            return services;
        }

        services.TryAddSingleton<IMongoDatabase>(_ =>
            new MongoClient(mongoDbOptions.ConnectionString)
                .GetDatabase(mongoDbOptions.Database));

        services.TryAddScoped(typeof(IMongoRepositoryBase<,>), typeof(MongoRepositoryBase<,>));
        return services;
    }
}